@@ -6,6 +6,8 @@ import annofabcli.statistics.list_annotation_count
 import annofabcli.statistics.list_cumulative_labor_time
 import annofabcli.statistics.list_labor_time_per_user
 import annofabcli.statistics.list_task_progress
+import annofabcli.statistics.summarize_task_count
+import annofabcli.statistics.summarize_task_count_by_task_id
 import annofabcli.statistics.visualize_statistics
 
 
@@ -18,6 +20,8 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.statistics.list_cumulative_labor_time.add_parser(subparsers)
     annofabcli.statistics.list_labor_time_per_user.add_parser(subparsers)
     annofabcli.statistics.list_task_progress.add_parser(subparsers)
+    annofabcli.statistics.summarize_task_count.add_parser(subparsers)
+    annofabcli.statistics.summarize_task_count_by_task_id.add_parser(subparsers)
     annofabcli.statistics.visualize_statistics.add_parser(subparsers)
 
 
